# pywattbox

For usage see: [eseglem/hass-wattbox][hass_wattbox]

Python wrapper for [WattBox][wattbox]

The documentation for the HTTP API was found [Here][http_api]
The documentation for Telnet / SSH API was found [Here][ssh_api]

I suggest not using the admin account to run this code. Log into your WattBox and create a new user account.

<!---->

***

[wattbox]: https://www.snapav.com/shop/en/snapav/wattbox
[hass_wattbox]: https://github.com/eseglem/hass-wattbox
[http_api]: https://www.snapav.com/wcsstore/ExtendedSitesCatalogAssetStore/attachments/documents/PowerManagement/SupportDocuments/Wattbox%20API%20v2.0.pdf
[ssh_api]: https://www.snapav.com/wcsstore/ExtendedSitesCatalogAssetStore/attachments/documents/PowerManagement/ProtocolsAndDrivers/SnapAV_Wattbox_API_V2.4.pdf
